@@ -1,14 +1,12 @@
 from django_digest import HttpDigestAuthenticator
-from django.conf import settings as django_settings
 from django_digest.utils import get_setting
 
 class HttpDigestMiddleware(object):
-    def __init__(self, require_authentication=None, authenticator=None,
-                 settings=django_settings):
+    def __init__(self, require_authentication=None, authenticator=None):
         if require_authentication == None:
-            require_authentication = get_setting(settings, 'DIGEST_REQUIRE_AUTHENTICATION',
+            require_authentication = get_setting('DIGEST_REQUIRE_AUTHENTICATION',
                                                  False)
-        self._authenticator = authenticator or HttpDigestAuthenticator(settings=settings)
+        self._authenticator = authenticator or HttpDigestAuthenticator()
         self._require_authentication = require_authentication
 
     def process_request(self, request):
