@@ -1,13 +1,15 @@
+from django.conf import settings
+
 DEFAULT_REALM = 'DJANGO'
 
-def get_setting(settings, setting_name, default=None):
+def get_setting(setting_name, default=None):
     if hasattr(settings, setting_name):
         return getattr(settings, setting_name)
     else:
         return default
 
-def get_backend(settings, setting_name, default_backend_class_path):
-    path = get_setting(settings, setting_name, default_backend_class_path)
+def get_backend(setting_name, default_backend_class_path):
+    path = get_setting(setting_name, default_backend_class_path)
 
     from django.core import exceptions
     from django.utils.importlib import import_module
@@ -28,3 +30,16 @@ def get_backend(settings, setting_name, default_backend_class_path):
                                               (path_components[0], path_components[1]))
 
     return cls()
+
+def get_default_db():
+    if not get_default_db._cache:
+        try:
+            from django.db import connections
+        except ImportError:
+            from django_digest.backend.db import FakeMultiDb
+            get_default_db._cache = FakeMultiDb()
+        else:
+            from django_digest.backend.db import MultiDb
+            get_default_db._cache = MultiDb(create=True)
+    return get_default_db._cache
+get_default_db._cache = None
